@@ -1,20 +1,7 @@
 /* This file is part of the KDE project
-   Copyright 2009 Pino Toscano <pino@kde.org>
+    SPDX-FileCopyrightText: 2009 Pino Toscano <pino@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "konqhistorymodel.h"
@@ -181,7 +168,7 @@ QVariant GroupEntry::data(int role, int /*column*/) const
             return QDateTime();
         }
         QDateTime dt = entries.first()->entry.lastVisited;
-        Q_FOREACH (HistoryEntry *e, entries) {
+        for (HistoryEntry *e: entries) {
             if (e->entry.lastVisited > dt) {
                 dt = e->entry.lastVisited;
             }
@@ -212,7 +199,7 @@ HistoryEntry *GroupEntry::findChild(const KonqHistoryEntry &entry, int *index) c
 QList<QUrl> GroupEntry::urls() const
 {
     QList<QUrl> list;
-    Q_FOREACH (HistoryEntry *e, entries) {
+    for (HistoryEntry *e: entries) {
         list.append(e->entry.url);
     }
     return list;
