@@ -11,7 +11,7 @@
 
 #include "kwebenginepartlib_export.h"
 
-#include "interfaces/downloaderextension.h"
+#include "interfaces/downloadjob.h"
 
 #include <QPointer>
 #include <QWebEngineDownloadRequest>
@@ -32,6 +32,8 @@ class QPrinter;
 class QJsonObject;
 class QWebEngineScript;
 
+class WebEngineDownloadJob;
+
 class KWEBENGINEPARTLIB_EXPORT WebEngineNavigationExtension : public BrowserExtension
 {
     Q_OBJECT
@@ -220,18 +222,4 @@ private:
     static SelectorInterface::Element jsonToElement(const QJsonObject &obj);
 };
 
-class WebEngineDownloaderExtension : public KonqInterfaces::DownloaderExtension
-{
-    Q_OBJECT
-public:
-    WebEngineDownloaderExtension(WebEnginePart *parent);
-    ~WebEngineDownloaderExtension();
-    KonqInterfaces::DownloaderJob* downloadJob(const QUrl &url, quint32 id, QObject *parent=nullptr) override;
-    void addDownloadRequest(QWebEngineDownloadRequest *req);
-    KParts::ReadOnlyPart* part() const override;
-
-private:
-    QMultiHash<QUrl, QWebEngineDownloadRequest*> m_downloadRequests;
-};
-
 #endif // WEBENGINEPART_EXT_H
